Module linkerd2_proxy_api::destination
source · Modules
- Generated client implementations.
- Generated server implementations.
- Nested message and enum types in
ProtocolHint. - Nested message and enum types in
RequestMatch. - Nested message and enum types in
ResponseMatch. - Nested message and enum types in
TlsIdentity. - Nested message and enum types in
Update.
Structs
- If either a minimum or maximum is not specified, the range is considered to be over a discrete value.
- A hint of what protocol the service knows. The default value is for the
hintfield to be not be set, essentially meaning “unknown”. - Which strategy should be used for verifying TLS.