pub struct GrpcFailureInjector {
pub code: u32,
pub message: String,
pub ratio: Option<Ratio>,
}Expand description
Configures a route to respond with a fixed response.
Fields
code: u32The status code to use in the grpc-status response. Must be specified.
message: StringAn error message to log and include in the grpc-message header.
ratio: Option<Ratio>If specified, the rate of requests that should be failed. If not specified, ALL requests are failed.