pub struct HttpFailureInjector {
pub status: u32,
pub message: String,
pub ratio: Option<Ratio>,
}Expand description
Configures a route to respond with a fixed response.
Fields
status: u32The status code to use in the HTTP response. Must be specified.
message: StringAn error message to log and include in the l5d-proxy-err header.
ratio: Option<Ratio>If specified, the rate of requests that should be failed. If not specified, ALL requests are failed.