Enum linkerd2_proxy_api::net::ip_address::Ip
source · pub enum Ip {
Ipv4(u32),
Ipv6(IPv6),
}Variants
Implementations
sourceimpl Ip
impl Ip
sourcepub fn merge<B>(
field: &mut Option<Ip>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>( field: &mut Option<Ip>, tag: u32, wire_type: WireType, buf: &mut B, ctx: DecodeContext ) -> Result<(), DecodeError>where B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.