Enum linkerd2_proxy_api::tap::tap_event::ProxyDirection
source · #[repr(i32)]
pub enum ProxyDirection {
Unknown,
Inbound,
Outbound,
}Variants
Implementations
sourceimpl ProxyDirection
impl ProxyDirection
sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.