pub trait Identity:
Send
+ Sync
+ 'static {
// Required method
fn certify<'life0, 'async_trait>(
&'life0 self,
request: Request<CertifyRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CertifyResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Generated trait containing gRPC methods that should be implemented for use with IdentityServer.
Required Methods
Sourcefn certify<'life0, 'async_trait>(
&'life0 self,
request: Request<CertifyRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CertifyResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn certify<'life0, 'async_trait>(
&'life0 self,
request: Request<CertifyRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CertifyResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Requests that a time-bounded certificate be signed.
The requester must provide a token that verifies the client’s identity and a Certificate Signing Request that adheres to the service naming rules.
Errors are returned when the provided request is invalid or when authentication cannot be performed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".