Modules
- backend
- Nested message and enum types in
Backend. - failure_
accrual - Nested message and enum types in
FailureAccrual. - grpc_
route - Nested message and enum types in
GrpcRoute. - http_
route - Nested message and enum types in
HttpRoute. - opaque_
route - Nested message and enum types in
OpaqueRoute. - outbound_
policies_ client - Generated client implementations.
- outbound_
policies_ server - Generated server implementations.
- proxy_
protocol - Nested message and enum types in
ProxyProtocol. - tls_
route - Nested message and enum types in
TlsRoute. - traffic_
spec - Nested message and enum types in
TrafficSpec.
Structs
- Backend
- Ejection
Config - Pool-level ejection protection. Prevents circuit breakers from ejecting all endpoints in a load-balancing pool.
- Exponential
Backoff - Failure
Accrual - Configures failure accrual policies for circuit breaking. Setting a numeric policy field to zero disables that policy.
- Grpc
Route - Http
Route - Outbound-specific HTTP route configuration (based on the Gateway API).
- Load
Bias Config - Configures load biasing for 429-aware load balancing. When enabled, the load balancer injects artificial penalties on rate-limited endpoints, causing P2C to prefer other endpoints.
- Opaque
Route - Outbound
Policy - Outbound policy for a given traffic spec.
- Proxy
Protocol - Queue
- Retry
After Config - Configures handling of rate-limiting hints: Retry-After headers (HTTP 429/503) and grpc-retry-pushback-ms trailers (gRPC RESOURCE_EXHAUSTED). The proxy uses the parsed duration to extend circuit breaker backoff and amplify load biaser penalties.
- TlsRoute
- Traffic
Spec